@@ -149,6 +149,7 @@ sub saveTextFh {
 
   foreach (sort {$scored->{$b} <=> $scored->{$a}} keys %$scored) {
     $fh->print(join("\t",
+		    map {$_//0}
 		    $Na, $Nb,
 		    $f1a,$f1b,
 		    $f2a->{$_}, $f2b->{$_},
@@ -243,7 +244,7 @@ our %DIFFOPS =
 sub diffop {
   my ($that,$op) = @_;
   $op //= $that->{diff} if (ref($that));
-  return $DIFFOPS{$op} // $op // $DIFFOPS{DEFAULT};
+  return (defined($op) ? $DIFFOPS{$op} : undef) // $op // $DIFFOPS{DEFAULT};
 }
 
 ## \&FUNC = $dprf->diffsub()
@@ -259,12 +260,22 @@ sub diffsub {
   return \&diffop_diff;
 }
 
-## $bool = $dprf->diffpretrim()
-## $bool = $CLASS_OR_OBJECT->diffpretrim($opNameOrAlias)
-##  + returns true iff diff should pre-trim operand profiles
+## $how = $dprf->diffpretrim()
+## $how = $CLASS_OR_OBJECT->diffpretrim($opNameOrAlias)
+##  + returns if and how diff should pre-trim operand profiles: one of:
+##    0          : don't pre-trim
+##    'restrict' : intersect defined collocates
+##    'kbest'    : union of k-best collocates
 sub diffpretrim {
   my ($that,$op) = @_;
-  return $that->diffop($op) =~ m/^a?diff|min|max/;
+  $op = $that->diffop($op);
+  if ($op =~ /^min|avg/) {
+    return 'restrict';
+  }
+  elsif ($op =~ m/^a?diff|max/) {
+    return 'kbest';
+  }
+  return 0;
 }
 
 ## $selector = $dprf->diffkbest()
@@ -310,7 +321,7 @@ sub diffop_lavg {
 
 ## $dprf = $dprf->populate()
 ## $dprf = $dprf->populate($prf1,$prf2)
-##  + populates diff-profile by subtracting $prf2 scores from $prf1
+##  + populates diff-profile by applying the selected diff-operation on aligned operand scores
 sub populate {
   my ($dprf,$pa,$pb) = @_;
   $pa //= $dprf->{prf1};
@@ -391,13 +402,8 @@ sub trim {
     $dprf->SUPER::trim(%opts) or return undef;
   }
   else {
-    ##-- heuristic trimming
-    if ($dprf->diffpretrim()) {
-      ##-- pre-trim operand profiles
-      my %abkeys = map {($_=>undef)} (($pa ? @{$pa->which(%opts)} : qw()), ($pb ? @{$pb->which(%opts)} : qw()));
-      $pa->trim(keep=>\%abkeys) if ($pa);
-      $pb->trim(keep=>\%abkeys) if ($pb);
-    }
+    ##-- heuristic (pre-)trimming
+    $dprf->pretrim($pa,$pb,%opts);
     $dprf->populate();
     $dprf->SUPER::trim(%opts);
   }
@@ -410,6 +416,28 @@ sub trim {
   return $dprf;
 }
 
+## ($pa,$pb) = $CLASS_OR_OBJECT->pretrim($pa,$pb,%opts)
+##   + perform pre-trimming on aligned profile pair ($pa,$pb)
+sub pretrim {
+  my ($that,$pa,$pb,%opts) = @_;
+  my $pretrim = $that->diffpretrim($opts{diff});
+
+  if ($pretrim eq 'kbest') {
+    ##-- pre-trim: union of k-best collocates
+    my %keep = map {($_=>undef)} (($pa ? @{$pa->which(%opts)} : qw()), ($pb ? @{$pb->which(%opts)} : qw()));
+    $pa->trim(keep=>\%keep);
+    $pb->trim(keep=>\%keep);
+  }
+  elsif ($pretrim eq 'restrict' && $pa && $pb) {
+    my @drop = (
+		(grep {!exists $pa->{f12}{$_}} keys %{$pb->{f12}}),
+		(grep {!exists $pb->{f12}{$_}} keys %{$pa->{f12}}),
+	       );
+    $pa->trim(drop=>\@drop);
+    $pb->trim(drop=>\@drop);
+  }
+  return ($pa,$pb);
+}
 
 ##==============================================================================
 ## Stringification
